@@ -73,13 +73,20 @@ def main(ctx, access_key, secret_key, host, debug):
     ctx.obj = _tla
 
 @main.command()
-# @click.option("-k", "--task_key", 'taskKey', default="", required=True, help="the task you wolud like to oprate")
-@click.argument("taskKey")
+@click.option("-k", "--task-key", 'taskKey', default="", required=True, help="the task you wolud like to oprate")
 @click.pass_context
 def template(ctx, taskKey):
     """ generate export code template """
     if ctx.obj == None:
         account._noLoginMessage()
+
+    if taskKey == "":
+        print(" you should specify which key you'd like to export, command:\n")
+        print("  tla template <taskKey> \n")
+        print(" more about this command, use：\n")
+        print("  tla config --help")
+        exit()
+
     codeContent=f"""from testinlabel.exportAbstract import ExportAbstract # warning: don't edit this line !!!
 from testinlabel.TLA import TLA     # warning: don't edit this line !!!
 
@@ -106,15 +113,24 @@ class Export(ExportAbstract):
 
 
 @main.command()
-# @click.option("-f", "--script-file", 'file', required=True, default="", help="script file path")
-@click.argument("scprit_path")
+@click.option("-f", "--script-file", 'file', required=True, default="", help="script file path")
 @click.pass_context
-def export(ctx, scprit_path):
+def export(ctx, file):
     """ exec export """
+
+    if file == "":
+        print(" you should specify where the script is, command:\n")
+        print("  tla export <scriptPath> \n")
+        print(" you need generate export code template before export, use:\n")
+        print("  tla template <taskKey> \n")
+        print(" more about this command, use：\n")
+        print("  tla export --help")
+        exit()
+
     if ctx.obj == None:
         account._noLoginMessage()
     try:
-        sys.path.append(os.path.split(scprit_path)[0])
+        sys.path.append(os.path.split(file)[0])
         from export import Export
         ex = Export(ctx.obj)
         ex.exec()
